Login to MGRAST, obtain your Websession and webkey for data uploading, as an authenticate of subsequent operation about MGRAST (e.g. data upload, job submission).
Usage
loginMgrast(user, userpwd)
Arguments
user
character, username you have registered on MGRAST
userpwd
character, password correspondance to your username
Value
webkeycharacter, e.g. "8Dvg2d5DCp7KsWKBPzY2GS4i", the webkey of your account which is essential for data uploding to MGRAST. However, it will be valid for a limited time only (the next value). Users will generate a new webkey with fucntion generateMgrastWebkey for convenient.
invalid.untilcharacter, with corresponding to the webkey, just the limit time of your webkey
cookiedata saved on user's computer while login to MGRAST
sessioncharacter, a userid that MGRAST server assigned
curlhandleclass of CURLHandle, the curl handle while users to MGRAST which is saved for user's sebsequent analysis with MGRAST.
Details
Sequence functional annotation is the most necessary and important step for metagenomic analysis. MGRAST (metagenomics RAST) server is a free and public utomated analysis platform for metagenomes providing quantitative insights into microbial populations based on sequence data, also very fast, stable and extensible. Thus, MGRAST was took for sequence functional annotation in our package mmnet.
Webkey, session and curlhandle would be generated when users login to MGRAST with this function, which is the key for data uploading and sequence annotation.